# swagger-client
This API allows you to explore the way candidates and committees fund their campaigns.    The FEC API is a RESTful web service supporting full-text and field-specific searches on FEC data. [Bulk downloads](https://www.fec.gov/data/advanced/?tab=bulk-data) are available on the current site. Information is tied to the underlying forms by file ID and image ID. Data is updated nightly.    There is a lot of data, but a good place to start is to use search to find interesting candidates and committees. Then, you can use their IDs to find report or line item details with the other endpoints. If you are interested in individual donors, check out contributor information in schedule_a.    Get an [API key here](https://api.data.gov/signup/). That will enable you to place up to 1,000 calls an hour. Each call is limited to 100 results per page. You can email questions, comments or a request to get a key for 120 calls per minute to [APIinfo@fec.gov](mailto:apiinfo@fec.gov). You can also ask questions and discuss the data in the [FEC data Google Group](https://groups.google.com/forum/#!forum/fec-data). API changes will also be added to this group in advance of the change.    The model definitions and schema are available at [/swagger](/swagger/). This is useful for making wrappers and exploring the data.    A few restrictions limit the way you can use FEC data. For example, you can’t use contributor lists for commercial purposes or to solicit donations. [Learn more here](https://www.fec.gov/updates/sale-or-use-contributor-information/).    [View our source code](https://github.com/fecgov/openFEC). We welcome issues and pull requests!

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import openfec_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openfec_sdk
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import openfec_sdk
from openfec_sdk.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyHeaderAuth
configuration = openfec_sdk.Configuration()
configuration.api_key['X-Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Api-Key'] = 'Bearer'
# Configure API key authorization: ApiKeyQueryAuth
configuration = openfec_sdk.Configuration()
configuration.api_key['api_key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'
# Configure API key authorization: apiKey
configuration = openfec_sdk.Configuration()
configuration.api_key['api_key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'

# create an instance of the API class
api_instance = openfec_sdk.AuditApi(openfec_sdk.ApiClient(configuration))
api_key = 'DEMO_KEY' # str |  API key for https://api.data.gov. Get one at https://api.data.gov/signup.  (default to DEMO_KEY)
primary_category_id = 'all' # str |  Audit category ID (table PK)  (optional) (default to all)
cycle = [56] # list[int] |  Filter records to only those that are applicable to a given two-year period. This cycle follows the traditional House election cycle and subdivides the presidential and Senate elections into comparable two-year blocks. The cycle begins with an odd year and is named for its ending, even year.  (optional)
sort = ['[-cycle, committee_name]'] # list[str] | Provide a field to sort by. Use - for descending order. (optional) (default to [-cycle, committee_name])
committee_type = ['committee_type_example'] # list[str] | The one-letter type code of the organization:         - C communication cost         - D delegate         - E electioneering communication         - H House         - I independent expenditor (person or group)         - N PAC - nonqualified         - O independent expenditure-only (super PACs)         - P presidential         - Q PAC - qualified         - S Senate         - U single candidate independent expenditure         - V PAC with non-contribution account, nonqualified         - W PAC with non-contribution account, qualified         - X party, nonqualified         - Y party, qualified         - Z national party non-federal account  (optional)
sort_nulls_last = false # bool | Toggle that sorts null values last (optional) (default to false)
q = ['q_example'] # list[str] | The name of the committee. If a committee changes its name,     the most recent name will be shown. Committee names are not unique. Use committee_id     for looking up records. (optional)
audit_case_id = ['audit_case_id_example'] # list[str] |  Primary/foreign key for audit tables  (optional)
sort_hide_null = false # bool | Hide null values on sorted column(s). (optional) (default to false)
max_election_cycle = 56 # int |  Filter records to only those that are applicable to a given two-year period. This cycle follows the traditional House election cycle and subdivides the presidential and Senate elections into comparable two-year blocks. The cycle begins with an odd year and is named for its ending, even year.  (optional)
min_election_cycle = 56 # int |  Filter records to only those that are applicable to a given two-year period. This cycle follows the traditional House election cycle and subdivides the presidential and Senate elections into comparable two-year blocks. The cycle begins with an odd year and is named for its ending, even year.  (optional)
committee_id = ['committee_id_example'] # list[str] |  A unique identifier assigned to each committee or filer registered with the FEC. In general committee id's begin with the letter C which is followed by eight digits.  (optional)
sub_category_id = 'all' # str |  The finding id of an audit. Finding are a category of broader issues. Each category has an unique ID.  (optional) (default to all)
per_page = 20 # int | The number of results returned per page. Defaults to 20. (optional) (default to 20)
candidate_id = ['candidate_id_example'] # list[str] |  A unique identifier assigned to each candidate registered with the FEC. If a person runs for several offices, that person will have separate candidate IDs for each office.  (optional)
page = 1 # int | For paginating through results, starting at page 1 (optional) (default to 1)
committee_designation = 'committee_designation_example' # str | Type of committee:         - H or S - Congressional         - P - Presidential         - X or Y or Z - Party         - N or Q - PAC         - I - Independent expenditure         - O - Super PAC   (optional)
audit_id = [56] # list[int] |  The audit issue. Each subcategory has an unique ID  (optional)
sort_null_only = false # bool | Toggle that filters out all rows having sort column that is non-null (optional) (default to false)
qq = ['qq_example'] # list[str] | Name of candidate running for office (optional)

try:
    api_response = api_instance.audit_case_get(api_key, primary_category_id=primary_category_id, cycle=cycle, sort=sort, committee_type=committee_type, sort_nulls_last=sort_nulls_last, q=q, audit_case_id=audit_case_id, sort_hide_null=sort_hide_null, max_election_cycle=max_election_cycle, min_election_cycle=min_election_cycle, committee_id=committee_id, sub_category_id=sub_category_id, per_page=per_page, candidate_id=candidate_id, page=page, committee_designation=committee_designation, audit_id=audit_id, sort_null_only=sort_null_only, qq=qq)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuditApi->audit_case_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuditApi* | [**audit_case_get**](docs/AuditApi.md#audit_case_get) | **GET** /audit-case/ |
*AuditApi* | [**audit_category_get**](docs/AuditApi.md#audit_category_get) | **GET** /audit-category/ |
*AuditApi* | [**audit_primary_category_get**](docs/AuditApi.md#audit_primary_category_get) | **GET** /audit-primary-category/ |
*AuditApi* | [**names_audit_candidates_get**](docs/AuditApi.md#names_audit_candidates_get) | **GET** /names/audit_candidates/ |
*AuditApi* | [**names_audit_committees_get**](docs/AuditApi.md#names_audit_committees_get) | **GET** /names/audit_committees/ |
*CandidateApi* | [**candidate_candidate_id_get**](docs/CandidateApi.md#candidate_candidate_id_get) | **GET** /candidate/{candidate_id}/ |
*CandidateApi* | [**candidate_candidate_id_history_cycle_get**](docs/CandidateApi.md#candidate_candidate_id_history_cycle_get) | **GET** /candidate/{candidate_id}/history/{cycle}/ |
*CandidateApi* | [**candidate_candidate_id_history_get**](docs/CandidateApi.md#candidate_candidate_id_history_get) | **GET** /candidate/{candidate_id}/history/ |
*CandidateApi* | [**candidate_candidate_id_totals_get**](docs/CandidateApi.md#candidate_candidate_id_totals_get) | **GET** /candidate/{candidate_id}/totals/ |
*CandidateApi* | [**candidates_get**](docs/CandidateApi.md#candidates_get) | **GET** /candidates/ |
*CandidateApi* | [**candidates_search_get**](docs/CandidateApi.md#candidates_search_get) | **GET** /candidates/search/ |
*CandidateApi* | [**candidates_totals_by_office_by_party_get**](docs/CandidateApi.md#candidates_totals_by_office_by_party_get) | **GET** /candidates/totals/by_office/by_party/ |
*CandidateApi* | [**candidates_totals_by_office_get**](docs/CandidateApi.md#candidates_totals_by_office_get) | **GET** /candidates/totals/by_office/ |
*CandidateApi* | [**candidates_totals_get**](docs/CandidateApi.md#candidates_totals_get) | **GET** /candidates/totals/ |
*CandidateApi* | [**committee_committee_id_candidates_get**](docs/CandidateApi.md#committee_committee_id_candidates_get) | **GET** /committee/{committee_id}/candidates/ |
*CandidateApi* | [**committee_committee_id_candidates_history_cycle_get**](docs/CandidateApi.md#committee_committee_id_candidates_history_cycle_get) | **GET** /committee/{committee_id}/candidates/history/{cycle}/ |
*CandidateApi* | [**committee_committee_id_candidates_history_get**](docs/CandidateApi.md#committee_committee_id_candidates_history_get) | **GET** /committee/{committee_id}/candidates/history/ |
*CommitteeApi* | [**candidate_candidate_id_committees_get**](docs/CommitteeApi.md#candidate_candidate_id_committees_get) | **GET** /candidate/{candidate_id}/committees/ |
*CommitteeApi* | [**candidate_candidate_id_committees_history_cycle_get**](docs/CommitteeApi.md#candidate_candidate_id_committees_history_cycle_get) | **GET** /candidate/{candidate_id}/committees/history/{cycle}/ |
*CommitteeApi* | [**candidate_candidate_id_committees_history_get**](docs/CommitteeApi.md#candidate_candidate_id_committees_history_get) | **GET** /candidate/{candidate_id}/committees/history/ |
*CommitteeApi* | [**committee_committee_id_get**](docs/CommitteeApi.md#committee_committee_id_get) | **GET** /committee/{committee_id}/ |
*CommitteeApi* | [**committee_committee_id_history_cycle_get**](docs/CommitteeApi.md#committee_committee_id_history_cycle_get) | **GET** /committee/{committee_id}/history/{cycle}/ |
*CommitteeApi* | [**committee_committee_id_history_get**](docs/CommitteeApi.md#committee_committee_id_history_get) | **GET** /committee/{committee_id}/history/ |
*CommitteeApi* | [**committees_get**](docs/CommitteeApi.md#committees_get) | **GET** /committees/ |
*CommunicationCostApi* | [**committee_committee_id_communication_costs_by_candidate_get**](docs/CommunicationCostApi.md#committee_committee_id_communication_costs_by_candidate_get) | **GET** /committee/{committee_id}/communication_costs/by_candidate/ |
*CommunicationCostApi* | [**communication_costs_aggregates_get**](docs/CommunicationCostApi.md#communication_costs_aggregates_get) | **GET** /communication_costs/aggregates/ |
*CommunicationCostApi* | [**communication_costs_by_candidate_get**](docs/CommunicationCostApi.md#communication_costs_by_candidate_get) | **GET** /communication_costs/by_candidate/ |
*CommunicationCostApi* | [**communication_costs_get**](docs/CommunicationCostApi.md#communication_costs_get) | **GET** /communication-costs/ |
*CommunicationCostApi* | [**communication_costs_totals_by_candidate_get**](docs/CommunicationCostApi.md#communication_costs_totals_by_candidate_get) | **GET** /communication_costs/totals/by_candidate/ |
*DatesApi* | [**calendar_dates_export_get**](docs/DatesApi.md#calendar_dates_export_get) | **GET** /calendar-dates/export/ |
*DatesApi* | [**calendar_dates_get**](docs/DatesApi.md#calendar_dates_get) | **GET** /calendar-dates/ |
*DatesApi* | [**election_dates_get**](docs/DatesApi.md#election_dates_get) | **GET** /election-dates/ |
*DatesApi* | [**reporting_dates_get**](docs/DatesApi.md#reporting_dates_get) | **GET** /reporting-dates/ |
*DebtsApi* | [**schedules_schedule_d_get**](docs/DebtsApi.md#schedules_schedule_d_get) | **GET** /schedules/schedule_d/ |
*DebtsApi* | [**schedules_schedule_d_sub_id_get**](docs/DebtsApi.md#schedules_schedule_d_sub_id_get) | **GET** /schedules/schedule_d/{sub_id}/ |
*DisbursementsApi* | [**schedules_schedule_b_by_purpose_get**](docs/DisbursementsApi.md#schedules_schedule_b_by_purpose_get) | **GET** /schedules/schedule_b/by_purpose/ |
*DisbursementsApi* | [**schedules_schedule_b_by_recipient_get**](docs/DisbursementsApi.md#schedules_schedule_b_by_recipient_get) | **GET** /schedules/schedule_b/by_recipient/ |
*DisbursementsApi* | [**schedules_schedule_b_by_recipient_id_get**](docs/DisbursementsApi.md#schedules_schedule_b_by_recipient_id_get) | **GET** /schedules/schedule_b/by_recipient_id/ |
*DisbursementsApi* | [**schedules_schedule_b_efile_get**](docs/DisbursementsApi.md#schedules_schedule_b_efile_get) | **GET** /schedules/schedule_b/efile/ |
*DisbursementsApi* | [**schedules_schedule_b_get**](docs/DisbursementsApi.md#schedules_schedule_b_get) | **GET** /schedules/schedule_b/ |
*DisbursementsApi* | [**schedules_schedule_b_sub_id_get**](docs/DisbursementsApi.md#schedules_schedule_b_sub_id_get) | **GET** /schedules/schedule_b/{sub_id}/ |
*EfilingApi* | [**efile_filings_get**](docs/EfilingApi.md#efile_filings_get) | **GET** /efile/filings/ |
*EfilingApi* | [**efile_reports_house_senate_get**](docs/EfilingApi.md#efile_reports_house_senate_get) | **GET** /efile/reports/house-senate/ |
*EfilingApi* | [**efile_reports_pac_party_get**](docs/EfilingApi.md#efile_reports_pac_party_get) | **GET** /efile/reports/pac-party/ |
*EfilingApi* | [**efile_reports_presidential_get**](docs/EfilingApi.md#efile_reports_presidential_get) | **GET** /efile/reports/presidential/ |
*ElectioneeringApi* | [**committee_committee_id_electioneering_by_candidate_get**](docs/ElectioneeringApi.md#committee_committee_id_electioneering_by_candidate_get) | **GET** /committee/{committee_id}/electioneering/by_candidate/ |
*ElectioneeringApi* | [**electioneering_aggregates_get**](docs/ElectioneeringApi.md#electioneering_aggregates_get) | **GET** /electioneering/aggregates/ |
*ElectioneeringApi* | [**electioneering_by_candidate_get**](docs/ElectioneeringApi.md#electioneering_by_candidate_get) | **GET** /electioneering/by_candidate/ |
*ElectioneeringApi* | [**electioneering_get**](docs/ElectioneeringApi.md#electioneering_get) | **GET** /electioneering/ |
*ElectioneeringApi* | [**electioneering_totals_by_candidate_get**](docs/ElectioneeringApi.md#electioneering_totals_by_candidate_get) | **GET** /electioneering/totals/by_candidate/ |
*FilerResourcesApi* | [**rad_analyst_get**](docs/FilerResourcesApi.md#rad_analyst_get) | **GET** /rad-analyst/ |
*FilerResourcesApi* | [**state_election_office_get**](docs/FilerResourcesApi.md#state_election_office_get) | **GET** /state-election-office/ |
*FilingsApi* | [**candidate_candidate_id_filings_get**](docs/FilingsApi.md#candidate_candidate_id_filings_get) | **GET** /candidate/{candidate_id}/filings/ |
*FilingsApi* | [**committee_committee_id_filings_get**](docs/FilingsApi.md#committee_committee_id_filings_get) | **GET** /committee/{committee_id}/filings/ |
*FilingsApi* | [**filings_get**](docs/FilingsApi.md#filings_get) | **GET** /filings/ |
*FilingsApi* | [**operations_log_get**](docs/FilingsApi.md#operations_log_get) | **GET** /operations-log/ |
*FinancialApi* | [**committee_committee_id_reports_get**](docs/FinancialApi.md#committee_committee_id_reports_get) | **GET** /committee/{committee_id}/reports/ |
*FinancialApi* | [**committee_committee_id_totals_get**](docs/FinancialApi.md#committee_committee_id_totals_get) | **GET** /committee/{committee_id}/totals/ |
*FinancialApi* | [**elections_get**](docs/FinancialApi.md#elections_get) | **GET** /elections/ |
*FinancialApi* | [**elections_search_get**](docs/FinancialApi.md#elections_search_get) | **GET** /elections/search/ |
*FinancialApi* | [**elections_summary_get**](docs/FinancialApi.md#elections_summary_get) | **GET** /elections/summary/ |
*FinancialApi* | [**reports_committee_type_get**](docs/FinancialApi.md#reports_committee_type_get) | **GET** /reports/{committee_type}/ |
*FinancialApi* | [**totals_by_entity_get**](docs/FinancialApi.md#totals_by_entity_get) | **GET** /totals/by_entity/ |
*FinancialApi* | [**totals_committee_type_get**](docs/FinancialApi.md#totals_committee_type_get) | **GET** /totals/{committee_type}/ |
*IndependentExpendituresApi* | [**schedules_schedule_e_by_candidate_get**](docs/IndependentExpendituresApi.md#schedules_schedule_e_by_candidate_get) | **GET** /schedules/schedule_e/by_candidate/ |
*IndependentExpendituresApi* | [**schedules_schedule_e_efile_get**](docs/IndependentExpendituresApi.md#schedules_schedule_e_efile_get) | **GET** /schedules/schedule_e/efile/ |
*IndependentExpendituresApi* | [**schedules_schedule_e_get**](docs/IndependentExpendituresApi.md#schedules_schedule_e_get) | **GET** /schedules/schedule_e/ |
*IndependentExpendituresApi* | [**schedules_schedule_e_totals_by_candidate_get**](docs/IndependentExpendituresApi.md#schedules_schedule_e_totals_by_candidate_get) | **GET** /schedules/schedule_e/totals/by_candidate/ |
*LegalApi* | [**legal_search_get**](docs/LegalApi.md#legal_search_get) | **GET** /legal/search/ |
*LoansApi* | [**schedules_schedule_c_get**](docs/LoansApi.md#schedules_schedule_c_get) | **GET** /schedules/schedule_c/ |
*LoansApi* | [**schedules_schedule_c_sub_id_get**](docs/LoansApi.md#schedules_schedule_c_sub_id_get) | **GET** /schedules/schedule_c/{sub_id}/ |
*PartyCoordinatedExpendituresApi* | [**schedules_schedule_f_get**](docs/PartyCoordinatedExpendituresApi.md#schedules_schedule_f_get) | **GET** /schedules/schedule_f/ |
*PartyCoordinatedExpendituresApi* | [**schedules_schedule_f_sub_id_get**](docs/PartyCoordinatedExpendituresApi.md#schedules_schedule_f_sub_id_get) | **GET** /schedules/schedule_f/{sub_id}/ |
*PresidentialApi* | [**presidential_contributions_by_candidate_get**](docs/PresidentialApi.md#presidential_contributions_by_candidate_get) | **GET** /presidential/contributions/by_candidate/ |
*PresidentialApi* | [**presidential_contributions_by_size_get**](docs/PresidentialApi.md#presidential_contributions_by_size_get) | **GET** /presidential/contributions/by_size/ |
*PresidentialApi* | [**presidential_contributions_by_state_get**](docs/PresidentialApi.md#presidential_contributions_by_state_get) | **GET** /presidential/contributions/by_state/ |
*PresidentialApi* | [**presidential_coverage_end_date_get**](docs/PresidentialApi.md#presidential_coverage_end_date_get) | **GET** /presidential/coverage_end_date/ |
*PresidentialApi* | [**presidential_financial_summary_get**](docs/PresidentialApi.md#presidential_financial_summary_get) | **GET** /presidential/financial_summary/ |
*ReceiptsApi* | [**schedules_schedule_a_by_employer_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_employer_get) | **GET** /schedules/schedule_a/by_employer/ |
*ReceiptsApi* | [**schedules_schedule_a_by_occupation_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_occupation_get) | **GET** /schedules/schedule_a/by_occupation/ |
*ReceiptsApi* | [**schedules_schedule_a_by_size_by_candidate_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_size_by_candidate_get) | **GET** /schedules/schedule_a/by_size/by_candidate/ |
*ReceiptsApi* | [**schedules_schedule_a_by_size_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_size_get) | **GET** /schedules/schedule_a/by_size/ |
*ReceiptsApi* | [**schedules_schedule_a_by_state_by_candidate_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_state_by_candidate_get) | **GET** /schedules/schedule_a/by_state/by_candidate/ |
*ReceiptsApi* | [**schedules_schedule_a_by_state_by_candidate_totals_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_state_by_candidate_totals_get) | **GET** /schedules/schedule_a/by_state/by_candidate/totals/ |
*ReceiptsApi* | [**schedules_schedule_a_by_state_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_state_get) | **GET** /schedules/schedule_a/by_state/ |
*ReceiptsApi* | [**schedules_schedule_a_by_state_totals_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_state_totals_get) | **GET** /schedules/schedule_a/by_state/totals/ |
*ReceiptsApi* | [**schedules_schedule_a_by_zip_get**](docs/ReceiptsApi.md#schedules_schedule_a_by_zip_get) | **GET** /schedules/schedule_a/by_zip/ |
*ReceiptsApi* | [**schedules_schedule_a_efile_get**](docs/ReceiptsApi.md#schedules_schedule_a_efile_get) | **GET** /schedules/schedule_a/efile/ |
*ReceiptsApi* | [**schedules_schedule_a_get**](docs/ReceiptsApi.md#schedules_schedule_a_get) | **GET** /schedules/schedule_a/ |
*ReceiptsApi* | [**schedules_schedule_a_sub_id_get**](docs/ReceiptsApi.md#schedules_schedule_a_sub_id_get) | **GET** /schedules/schedule_a/{sub_id}/ |
*SearchApi* | [**names_candidates_get**](docs/SearchApi.md#names_candidates_get) | **GET** /names/candidates/ |
*SearchApi* | [**names_committees_get**](docs/SearchApi.md#names_committees_get) | **GET** /names/committees/ |


## Documentation For Models

 - [AuditCandidateSearch](docs/AuditCandidateSearch.md)
 - [AuditCandidateSearchList](docs/AuditCandidateSearchList.md)
 - [AuditCase](docs/AuditCase.md)
 - [AuditCaseCategoryRelation](docs/AuditCaseCategoryRelation.md)
 - [AuditCaseCategoryRelationPage](docs/AuditCaseCategoryRelationPage.md)
 - [AuditCasePage](docs/AuditCasePage.md)
 - [AuditCaseSubCategory](docs/AuditCaseSubCategory.md)
 - [AuditCaseSubCategoryPage](docs/AuditCaseSubCategoryPage.md)
 - [AuditCategory](docs/AuditCategory.md)
 - [AuditCategoryPage](docs/AuditCategoryPage.md)
 - [AuditCategoryRelation](docs/AuditCategoryRelation.md)
 - [AuditCategoryRelationPage](docs/AuditCategoryRelationPage.md)
 - [AuditCommitteeSearch](docs/AuditCommitteeSearch.md)
 - [AuditCommitteeSearchList](docs/AuditCommitteeSearchList.md)
 - [AuditPrimaryCategory](docs/AuditPrimaryCategory.md)
 - [AuditPrimaryCategoryPage](docs/AuditPrimaryCategoryPage.md)
 - [BaseF3Filing](docs/BaseF3Filing.md)
 - [BaseF3FilingPage](docs/BaseF3FilingPage.md)
 - [BaseF3PFiling](docs/BaseF3PFiling.md)
 - [BaseF3PFilingPage](docs/BaseF3PFilingPage.md)
 - [BaseF3XFiling](docs/BaseF3XFiling.md)
 - [BaseF3XFilingPage](docs/BaseF3XFilingPage.md)
 - [CCTotalsByCandidate](docs/CCTotalsByCandidate.md)
 - [CCTotalsByCandidatePage](docs/CCTotalsByCandidatePage.md)
 - [CalendarDate](docs/CalendarDate.md)
 - [CalendarDatePage](docs/CalendarDatePage.md)
 - [Candidate](docs/Candidate.md)
 - [CandidateCommitteeTotalsHouseSenate](docs/CandidateCommitteeTotalsHouseSenate.md)
 - [CandidateCommitteeTotalsHouseSenatePage](docs/CandidateCommitteeTotalsHouseSenatePage.md)
 - [CandidateCommitteeTotalsPresidential](docs/CandidateCommitteeTotalsPresidential.md)
 - [CandidateCommitteeTotalsPresidentialPage](docs/CandidateCommitteeTotalsPresidentialPage.md)
 - [CandidateDetail](docs/CandidateDetail.md)
 - [CandidateDetailPage](docs/CandidateDetailPage.md)
 - [CandidateFlags](docs/CandidateFlags.md)
 - [CandidateFlagsPage](docs/CandidateFlagsPage.md)
 - [CandidateHistory](docs/CandidateHistory.md)
 - [CandidateHistoryPage](docs/CandidateHistoryPage.md)
 - [CandidateHistoryTotal](docs/CandidateHistoryTotal.md)
 - [CandidateHistoryTotalPage](docs/CandidateHistoryTotalPage.md)
 - [CandidatePage](docs/CandidatePage.md)
 - [CandidateSearch](docs/CandidateSearch.md)
 - [CandidateSearchList](docs/CandidateSearchList.md)
 - [CandidateTotal](docs/CandidateTotal.md)
 - [CandidateTotalPage](docs/CandidateTotalPage.md)
 - [Committee](docs/Committee.md)
 - [CommitteeDetail](docs/CommitteeDetail.md)
 - [CommitteeDetailPage](docs/CommitteeDetailPage.md)
 - [CommitteeHistory](docs/CommitteeHistory.md)
 - [CommitteeHistoryPage](docs/CommitteeHistoryPage.md)
 - [CommitteePage](docs/CommitteePage.md)
 - [CommitteeReports](docs/CommitteeReports.md)
 - [CommitteeReportsHouseSenate](docs/CommitteeReportsHouseSenate.md)
 - [CommitteeReportsHouseSenatePage](docs/CommitteeReportsHouseSenatePage.md)
 - [CommitteeReportsIEOnly](docs/CommitteeReportsIEOnly.md)
 - [CommitteeReportsIEOnlyPage](docs/CommitteeReportsIEOnlyPage.md)
 - [CommitteeReportsPacParty](docs/CommitteeReportsPacParty.md)
 - [CommitteeReportsPacPartyPage](docs/CommitteeReportsPacPartyPage.md)
 - [CommitteeReportsPage](docs/CommitteeReportsPage.md)
 - [CommitteeReportsPresidential](docs/CommitteeReportsPresidential.md)
 - [CommitteeReportsPresidentialPage](docs/CommitteeReportsPresidentialPage.md)
 - [CommitteeSearch](docs/CommitteeSearch.md)
 - [CommitteeSearchList](docs/CommitteeSearchList.md)
 - [CommitteeTotals](docs/CommitteeTotals.md)
 - [CommitteeTotalsHouseSenate](docs/CommitteeTotalsHouseSenate.md)
 - [CommitteeTotalsHouseSenatePage](docs/CommitteeTotalsHouseSenatePage.md)
 - [CommitteeTotalsIEOnly](docs/CommitteeTotalsIEOnly.md)
 - [CommitteeTotalsIEOnlyPage](docs/CommitteeTotalsIEOnlyPage.md)
 - [CommitteeTotalsPacParty](docs/CommitteeTotalsPacParty.md)
 - [CommitteeTotalsPacPartyPage](docs/CommitteeTotalsPacPartyPage.md)
 - [CommitteeTotalsPage](docs/CommitteeTotalsPage.md)
 - [CommitteeTotalsPerCycle](docs/CommitteeTotalsPerCycle.md)
 - [CommitteeTotalsPerCyclePage](docs/CommitteeTotalsPerCyclePage.md)
 - [CommitteeTotalsPresidential](docs/CommitteeTotalsPresidential.md)
 - [CommitteeTotalsPresidentialPage](docs/CommitteeTotalsPresidentialPage.md)
 - [CommunicationCost](docs/CommunicationCost.md)
 - [CommunicationCostByCandidate](docs/CommunicationCostByCandidate.md)
 - [CommunicationCostByCandidatePage](docs/CommunicationCostByCandidatePage.md)
 - [CommunicationCostPage](docs/CommunicationCostPage.md)
 - [ECTotalsByCandidate](docs/ECTotalsByCandidate.md)
 - [ECTotalsByCandidatePage](docs/ECTotalsByCandidatePage.md)
 - [EFilings](docs/EFilings.md)
 - [EFilingsPage](docs/EFilingsPage.md)
 - [EfilingsAmendments](docs/EfilingsAmendments.md)
 - [EfilingsAmendmentsPage](docs/EfilingsAmendmentsPage.md)
 - [Election](docs/Election.md)
 - [ElectionDate](docs/ElectionDate.md)
 - [ElectionDatePage](docs/ElectionDatePage.md)
 - [ElectionPage](docs/ElectionPage.md)
 - [ElectionSearch](docs/ElectionSearch.md)
 - [ElectionSearchPage](docs/ElectionSearchPage.md)
 - [ElectionSummary](docs/ElectionSummary.md)
 - [Electioneering](docs/Electioneering.md)
 - [ElectioneeringByCandidate](docs/ElectioneeringByCandidate.md)
 - [ElectioneeringByCandidatePage](docs/ElectioneeringByCandidatePage.md)
 - [ElectioneeringPage](docs/ElectioneeringPage.md)
 - [ElectionsList](docs/ElectionsList.md)
 - [ElectionsListPage](docs/ElectionsListPage.md)
 - [EntityReceiptDisbursementTotals](docs/EntityReceiptDisbursementTotals.md)
 - [EntityReceiptDisbursementTotalsPage](docs/EntityReceiptDisbursementTotalsPage.md)
 - [Filings](docs/Filings.md)
 - [FilingsPage](docs/FilingsPage.md)
 - [IETotalsByCandidate](docs/IETotalsByCandidate.md)
 - [IETotalsByCandidatePage](docs/IETotalsByCandidatePage.md)
 - [InlineResponseDefault](docs/InlineResponseDefault.md)
 - [InlineResponseDefault1](docs/InlineResponseDefault1.md)
 - [InlineResponseDefault1AdminFines](docs/InlineResponseDefault1AdminFines.md)
 - [InlineResponseDefault1Adrs](docs/InlineResponseDefault1Adrs.md)
 - [InlineResponseDefault1AdvisoryOpinions](docs/InlineResponseDefault1AdvisoryOpinions.md)
 - [InlineResponseDefault1AoCitations](docs/InlineResponseDefault1AoCitations.md)
 - [InlineResponseDefault1Citations](docs/InlineResponseDefault1Citations.md)
 - [InlineResponseDefault1CommissionVotes](docs/InlineResponseDefault1CommissionVotes.md)
 - [InlineResponseDefault1Dispositions](docs/InlineResponseDefault1Dispositions.md)
 - [InlineResponseDefault1Documents](docs/InlineResponseDefault1Documents.md)
 - [InlineResponseDefault1Documents1](docs/InlineResponseDefault1Documents1.md)
 - [InlineResponseDefault1Entities](docs/InlineResponseDefault1Entities.md)
 - [InlineResponseDefault1Murs](docs/InlineResponseDefault1Murs.md)
 - [InlineResponseDefault1Participants](docs/InlineResponseDefault1Participants.md)
 - [InlineResponseDefault1Regulations](docs/InlineResponseDefault1Regulations.md)
 - [InlineResponseDefault1RegulatoryCitations](docs/InlineResponseDefault1RegulatoryCitations.md)
 - [InlineResponseDefault1Statutes](docs/InlineResponseDefault1Statutes.md)
 - [InlineResponseDefault1StatutoryCitations](docs/InlineResponseDefault1StatutoryCitations.md)
 - [InlineResponseDefault2](docs/InlineResponseDefault2.md)
 - [InlineResponseDefault3](docs/InlineResponseDefault3.md)
 - [InlineResponseDefault3Results](docs/InlineResponseDefault3Results.md)
 - [InlineResponseDefault4](docs/InlineResponseDefault4.md)
 - [InlineResponseDefault4Results](docs/InlineResponseDefault4Results.md)
 - [InlineResponseDefault5](docs/InlineResponseDefault5.md)
 - [InlineResponseDefault5Results](docs/InlineResponseDefault5Results.md)
 - [OffsetInfo](docs/OffsetInfo.md)
 - [OperationsLog](docs/OperationsLog.md)
 - [OperationsLogPage](docs/OperationsLogPage.md)
 - [PresidentialByCandidate](docs/PresidentialByCandidate.md)
 - [PresidentialByCandidatePage](docs/PresidentialByCandidatePage.md)
 - [PresidentialBySize](docs/PresidentialBySize.md)
 - [PresidentialBySizePage](docs/PresidentialBySizePage.md)
 - [PresidentialByState](docs/PresidentialByState.md)
 - [PresidentialByStatePage](docs/PresidentialByStatePage.md)
 - [PresidentialCoverage](docs/PresidentialCoverage.md)
 - [PresidentialCoveragePage](docs/PresidentialCoveragePage.md)
 - [PresidentialSummary](docs/PresidentialSummary.md)
 - [PresidentialSummaryPage](docs/PresidentialSummaryPage.md)
 - [RadAnalyst](docs/RadAnalyst.md)
 - [RadAnalystPage](docs/RadAnalystPage.md)
 - [ReportDate](docs/ReportDate.md)
 - [ReportDatePage](docs/ReportDatePage.md)
 - [ReportType](docs/ReportType.md)
 - [ScheduleA](docs/ScheduleA.md)
 - [ScheduleAByEmployer](docs/ScheduleAByEmployer.md)
 - [ScheduleAByEmployerPage](docs/ScheduleAByEmployerPage.md)
 - [ScheduleAByOccupation](docs/ScheduleAByOccupation.md)
 - [ScheduleAByOccupationPage](docs/ScheduleAByOccupationPage.md)
 - [ScheduleABySize](docs/ScheduleABySize.md)
 - [ScheduleABySizeCandidate](docs/ScheduleABySizeCandidate.md)
 - [ScheduleABySizeCandidatePage](docs/ScheduleABySizeCandidatePage.md)
 - [ScheduleABySizePage](docs/ScheduleABySizePage.md)
 - [ScheduleAByState](docs/ScheduleAByState.md)
 - [ScheduleAByStateCandidate](docs/ScheduleAByStateCandidate.md)
 - [ScheduleAByStateCandidatePage](docs/ScheduleAByStateCandidatePage.md)
 - [ScheduleAByStatePage](docs/ScheduleAByStatePage.md)
 - [ScheduleAByStateRecipientTotals](docs/ScheduleAByStateRecipientTotals.md)
 - [ScheduleAByStateRecipientTotalsPage](docs/ScheduleAByStateRecipientTotalsPage.md)
 - [ScheduleAByZip](docs/ScheduleAByZip.md)
 - [ScheduleAByZipPage](docs/ScheduleAByZipPage.md)
 - [ScheduleAEfile](docs/ScheduleAEfile.md)
 - [ScheduleAEfilePage](docs/ScheduleAEfilePage.md)
 - [ScheduleAPage](docs/ScheduleAPage.md)
 - [ScheduleB](docs/ScheduleB.md)
 - [ScheduleBByPurpose](docs/ScheduleBByPurpose.md)
 - [ScheduleBByPurposePage](docs/ScheduleBByPurposePage.md)
 - [ScheduleBByRecipient](docs/ScheduleBByRecipient.md)
 - [ScheduleBByRecipientID](docs/ScheduleBByRecipientID.md)
 - [ScheduleBByRecipientIDPage](docs/ScheduleBByRecipientIDPage.md)
 - [ScheduleBByRecipientPage](docs/ScheduleBByRecipientPage.md)
 - [ScheduleBEfile](docs/ScheduleBEfile.md)
 - [ScheduleBEfilePage](docs/ScheduleBEfilePage.md)
 - [ScheduleBPage](docs/ScheduleBPage.md)
 - [ScheduleE](docs/ScheduleE.md)
 - [ScheduleEByCandidate](docs/ScheduleEByCandidate.md)
 - [ScheduleEByCandidatePage](docs/ScheduleEByCandidatePage.md)
 - [ScheduleEEfile](docs/ScheduleEEfile.md)
 - [ScheduleEEfilePage](docs/ScheduleEEfilePage.md)
 - [ScheduleEPage](docs/ScheduleEPage.md)
 - [ScheduleH4](docs/ScheduleH4.md)
 - [ScheduleH4Page](docs/ScheduleH4Page.md)
 - [SeekInfo](docs/SeekInfo.md)
 - [StateElectionOfficeInfo](docs/StateElectionOfficeInfo.md)
 - [StateElectionOfficeInfoPage](docs/StateElectionOfficeInfoPage.md)
 - [TotalByOffice](docs/TotalByOffice.md)
 - [TotalByOfficeByParty](docs/TotalByOfficeByParty.md)
 - [TotalByOfficeByPartyPage](docs/TotalByOfficeByPartyPage.md)
 - [TotalByOfficePage](docs/TotalByOfficePage.md)
 - [TotalsCommittee](docs/TotalsCommittee.md)
 - [TotalsCommitteePage](docs/TotalsCommitteePage.md)


## Documentation For Authorization


## ApiKeyHeaderAuth

- **Type**: API key
- **API key parameter name**: X-Api-Key
- **Location**: HTTP header

## ApiKeyQueryAuth

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: URL query string

## apiKey

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: URL query string


## Author
